@@ -5,9 +5,6 @@
 import numpy as np
 import time
 
-def version():
-    print("Version 0.0002");
-
 #Transpose of 3x3 matrix
 def transpose(x): 
     a11 = x[0,0]
@@ -495,6 +492,65 @@ def reshape_ntnznynx(path):
             nD[t,:,:,i] = data[i,:,:,t].T
     np.save(path,nD)
 
+def sampleplume2d(gprime,threshold,dt,dz,dy,dx,D):
+    import warnings
+    warnings.filterwarnings("ignore")
+    import matplotlib.pyplot as plt
+    gprimemax = np.max(gprime)
+    nt,nz,ny,nx = np.shape(gprime)
+    x = np.linspace(0,nz*dz/D,9)
+    y = np.linspace(0,nz*dz/D,9)
+    for t in range(0,nt,int(nt/10)):
+        dataQx = gprime[t,:,int(ny/2),:]/gprimemax
+        interfacex = gprime[t,:,int(ny/2),:]/gprimemax
+        interfacex[interfacex<threshold] = 0
+        interfacex[interfacex>0] = 1
+        
+        dataQy = gprime[t,:,:,int(nx/2)]/gprimemax
+        interfacey = gprime[t,:,:,int(nx/2)]/gprimemax
+        interfacey[interfacey<threshold] = 0
+        interfacey[interfacey>0] = 1
+        
+        fig,ax=plt.subplots(1,2,sharey=False,figsize=(11,5))
+        ax[0].contourf(dataQx,vmin=0,vmax=0.5)
+        ax[0].contour(interfacex,colors="black",levels=20)
+        ax[1].contourf(dataQy,vmin=0,vmax=0.5)
+        ax[1].contour(interfacey,colors="black",levels=20)
+        ax[0].set_title("Time: "+str(t)+"s")
+        ax[1].set_title("Time: "+str(t)+"s")
+        ax[0].set_xticks(np.linspace(0,nx-1,5))
+        ax[0].set_xticklabels(np.linspace(-nx*dx/2/D,nx*dx/2/D,5))
+        ax[1].set_xticks(np.linspace(0,ny-1,5))
+        ax[1].set_xticklabels(np.linspace(-ny*dy/2/D,ny*dy/2/D,5))
+        ax[0].set_ylabel("z/D")
+        ax[0].set_xlabel("x/D")
+        ax[1].set_xlabel("y/D")
+        ax[1].set_ylabel("z/D")
+        ax[0].set_yticklabels(y)
+        ax[1].set_yticklabels(y)
+        plt.show()
+
+def frontplot(frontheight,frontvelocity,nz,dz,dt,D):
+    import warnings
+    warnings.filterwarnings("ignore")
+    import matplotlib.pyplot as plt
+    ntf = int(np.shape(frontheight)[0])
+    fig,ax=plt.subplots(2,1,sharey=False,figsize=(6,10))
+    ax[0].plot(frontheight,'k--')
+    ax[1].plot(frontvelocity,'k--')
+    ax[0].set_title("Plume Front Height")
+    ax[1].set_title("Plume Front Velocity")
+    ax[0].set_xticks(np.linspace(0,ntf-1,6))
+    ax[0].set_xticklabels(np.linspace(0,ntf*dt,6))
+    ax[1].set_xticks(np.linspace(0,ntf-1,6))
+    ax[1].set_xticklabels(np.linspace(0,ntf*dt,6))
+    ax[0].set_ylabel("z/D")
+    ax[0].set_xlabel("Time(s)")
+    ax[1].set_xlabel("Time(s)")
+    ax[1].set_ylabel("Uf(m/s)")
+    ax[0].set_yticklabels(np.linspace(0,nz*dz/D,9))
+    plt.show()
+
 # def hf_csv2array (data):
 #     temp = np.array(data)
 #     nt = np.shape(temp)[0]
@@ -679,9 +735,12 @@ class plume_metadata:
         self.density_amb = namelist_dictionary["density_ambient"]
 
 class plume_metrics:
-    def __init__(self,gT,W,dt,dz,dy,dx,D,threshold,Ta,g,density_ref,density_amb):
-        self.front_height = plumeheight(gT,threshold,dt,dz);
-        self.front_velocity = frontvelocity(gT,threshold,dt,dz);
+    def __init__(self,gprime,dt,dz,dy,dx,D,threshold,Ta,g,density_ref,density_amb):
+        nt,nz,ny,nx = np.shape(gprime)
+        self.front_height = plumeheight(gprime,threshold,dt,dz);
+        self.front_velocity = frontvelocity(gprime,threshold,dt,dz);
+        frontplot(self.front_height,self.front_velocity,nz,dz,dt,D)
+        sampleplume2d(gprime,threshold,dt,dz,dy,dx,D);
     
 class plume_polar_coordinates:
     def __init__(self,dataU,dataV,dataW,dz,dy,dx):
